"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformAddRouteItem = exports.transformAddRouteImport = exports.addMvpAppMenu = void 0;
const path_1 = __importDefault(require("path"));
const jscodeshift_1 = __importStar(require("jscodeshift"));
const utils_1 = require("../../../../../common/utils");
const j = jscodeshift_1.default;
function addMvpAppMenu({ gen, dirShift, route, componentName, menuItemName, pathToComponent }) {
    const destRoot = gen.destinationRoot();
    const srcDir = path_1.default.join(destRoot, dirShift ? dirShift : '');
    // Add menu item
    const appMenuPath = path_1.default.join(srcDir, 'app', 'menu', 'Menu.tsx');
    if (!gen.fs.exists(appMenuPath)) {
        gen.log('Unable to add component to menu: app menu not found');
        return;
    }
    const appMenuContents = gen.fs.read(appMenuPath);
    const appMenuTransformed = transformAddMenuItem(appMenuContents, route, componentName, menuItemName);
    gen.fs.write(appMenuPath, appMenuTransformed);
    gen.log(`✓ Menu item added for ${componentName}`);
    // Add route
    const routeConfigPath = path_1.default.join(srcDir, 'app', 'routes', 'AppRoutes.tsx');
    if (!gen.fs.exists(routeConfigPath)) {
        gen.log('Unable to add component: route config not found');
        return;
    }
    const routeConfigFileContent = gen.fs.read(routeConfigPath);
    let routeConfigTransformed;
    routeConfigTransformed = transformAddRouteItem(routeConfigFileContent, route, componentName);
    gen.log(`✓ Route item added for ${componentName}`);
    const componentPath = pathToComponent ?? `${getRelativePath(path_1.default.join(srcDir, 'app/routes'), destRoot)}/${componentName}`;
    routeConfigTransformed = transformAddRouteImport(routeConfigTransformed, componentName, componentPath);
    gen.fs.write(routeConfigPath, routeConfigTransformed);
    gen.log(`✓ Route import for ${componentName}`);
}
exports.addMvpAppMenu = addMvpAppMenu;
function transformAddMenuItem(source, route, componentName, menuItemName) {
    const menuItemJSX = createMenuItemJSX(route, componentName, menuItemName);
    const tsxParser = j.withParser('tsx');
    const appMenuAST = tsxParser(source);
    const menu = appMenuAST.findJSXElements('Menu');
    const [{ value: { children } }] = menu.paths();
    children?.push(jscodeshift_1.stringLiteral(menuItemJSX));
    return appMenuAST.toSource();
}
function transformAddRouteImport(source, componentName, componentPath, isDefault = false) {
    const tsxParser = j.withParser('tsx');
    const ast = tsxParser(source);
    const existingSpecifiers = ast.find(j.ImportDeclaration)
        .find(j.ImportSpecifier)
        .filter(path => path.node.imported.name === componentName);
    const alreadyImported = existingSpecifiers.length > 0;
    if (alreadyImported) {
        return source;
    }
    const importSpecifier = isDefault ? j.importDefaultSpecifier : j.importSpecifier;
    const newImport = j.importDeclaration([importSpecifier(j.identifier(componentName))], j.stringLiteral(componentPath));
    ast.get().node.program.body.unshift(newImport);
    return ast.toSource();
}
exports.transformAddRouteImport = transformAddRouteImport;
function transformAddRouteItem(source, route, componentName) {
    const tsxParser = j.withParser('tsx');
    const routeConfigAST = tsxParser(source);
    const menu = routeConfigAST.findJSXElements('Routes');
    const [{ value: { children } }] = menu.paths();
    const routeItemJSX = createRouteItemJSX(route, componentName);
    children?.push(jscodeshift_1.stringLiteral(routeItemJSX));
    return routeConfigAST.toSource();
}
exports.transformAddRouteItem = transformAddRouteItem;
function createMenuItemJSX(route, componentName, menuItemName) {
    return `
    <Menu.Item title={intl.formatMessage({id: 'screen.${menuItemName ?? componentName}'})}
               key={'/${route}'}
    >
      <Link to={'/${route}'}>
        <FormattedMessage id={'screen.${menuItemName ?? componentName}'} />
      </Link>
    </Menu.Item>
  `;
}
function createRouteItemJSX(route, componentName) {
    return `
    <Route path="${route}">
      <Route index element={<${componentName}/>} />
      <Route path=":recordId" element={<${componentName}/>} />
    </Route>
  `;
}
function getRelativePath(routingDir, destRoot) {
    return utils_1.convertToUnixPath(path_1.default.relative(routingDir, destRoot));
}
//# sourceMappingURL=addMvpAppMenu.js.map